# README

This repository contains the notebooks for this week's assignment. Complete
the homework in each .ipynb notebook, commit your work, and push the changes
to github. Your instructor will pull the completed assignment after the
deadline.

Once grading is complete, your instructor will push the results to a file
called `feedback.html`. You will need to pull the changes to your local copy
and open this file in a browser to view (because GitHub will not render html 
files).
